katsdpsigproc.test package
==========================

Submodules
----------

katsdpsigproc.test.test_accel module
------------------------------------

.. automodule:: katsdpsigproc.test.test_accel
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_fill module
-----------------------------------

.. automodule:: katsdpsigproc.test.test_fill
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_maskedsum module
----------------------------------------

.. automodule:: katsdpsigproc.test.test_maskedsum
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_percentile module
-----------------------------------------

.. automodule:: katsdpsigproc.test.test_percentile
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_rank module
-----------------------------------

.. automodule:: katsdpsigproc.test.test_rank
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_reduce module
-------------------------------------

.. automodule:: katsdpsigproc.test.test_reduce
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_resource module
---------------------------------------

.. automodule:: katsdpsigproc.test.test_resource
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_transpose module
----------------------------------------

.. automodule:: katsdpsigproc.test.test_transpose
    :members:
    :undoc-members:
    :show-inheritance:

katsdpsigproc.test.test_tune module
-----------------------------------

.. automodule:: katsdpsigproc.test.test_tune
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: katsdpsigproc.test
    :members:
    :undoc-members:
    :show-inheritance:
